# nafha

> نفحه الجنه

- [AI convo](https://chatgpt.com/c/68de9027-4d3c-8326-997a-c1f6669e0282)
- caused [pwm generator](../pwm-generator.md)

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/blob/main/nafha/01.png?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/01.png?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/02.png?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/02.png?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/03.png?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/03.png?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/nafha/04.png?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/04.png?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251028_123428.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251028_123428.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251028_123438.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251028_123438.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215221.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215221.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215248.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215248.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215253.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215253.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215257.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215257.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215301.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215301.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215319.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251103_215319.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251116_224456.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251116_224456.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251124_094940.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251124_094940.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/nafha/20251125_203403.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/nafha/20251125_203403.jpg?raw=true) |

## parts

continues [v1](./parts-v1.md), [v2](./parts-v2.md).

|   |   |   |   |   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| [`DC power jack, 5.5 mm`](../parts/dc-power-jack.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charger-socket.jpg?raw=true)](../parts/dc-power-jack.md)  | [`DC power plug, 5.5 mm`](../parts/dc-power-plug.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charging-port.jpg?raw=true)](../parts/dc-power-plug.md)  | [`DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter`](../parts/dsn-vc288.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](../parts/dsn-vc288.md)  | [`Li-Ion battery`](../parts/li-ion-battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/lithium-battery.jpg?raw=true)](../parts/li-ion-battery.md) option 2️⃣, e.g. 3 x 26650, 5000 mAh 5C, 3.7 V/4.2 V | [`Rechargeable sealed lead acid battery`](../parts/SLA-Battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/battery.png?raw=true)](../parts/SLA-Battery.md) option 1️⃣, e.g. 12 V, 7.2 Ah | [`auto power connectors`](../parts/connector.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/connector.jpg?raw=true)](../parts/connector.md) 1 male | [`heater element`](../parts/heater-element.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/heater-element.jpg?raw=true)](../parts/heater-element.md) 12 V, 4.5 Ω, 32 w | [`nuts, bolts, and spacers`](../parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](../parts/nuts-bolts-spacers.md) M3: (4 x bolt + 4 x nut + 4 x 40 mm spacer) | [`on/off DC switch with indicator led`](../parts/dc-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/on-off-switch.png?raw=true)](../parts/dc-switch.md) 12V DC 10 A | [`plexiglass, 2 mm or 2.5 mm thickness`](../parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](../parts/plexiglass.md) 2 x 80 cm x 100 cm |
| [`pwm manual DC motor controller, 12 V, ≥ 5 A`](../parts/pwm-manual-dc-motor-controller.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pwm-manual-dc-motor-controller.jpg?raw=true)](../parts/pwm-manual-dc-motor-controller.md)  |  |  |  |  |  |  |  |  |  |

1. [DC power jack, 5.5 mm](../parts/dc-power-jack.md).
1. [DC power plug, 5.5 mm](../parts/dc-power-plug.md).
1. [DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter](../parts/dsn-vc288.md).
1. [Li-Ion battery](../parts/li-ion-battery.md): option 2️⃣, e.g. 3 x 26650, 5000 mAh 5C, 3.7 V/4.2 V.
1. [Rechargeable sealed lead acid battery](../parts/SLA-Battery.md): option 1️⃣, e.g. 12 V, 7.2 Ah.
1. [auto power connectors](../parts/connector.md): 1 male.
1. [heater element](../parts/heater-element.md): 12 V, 4.5 Ω, 32 w.
1. [nuts, bolts, and spacers](../parts/nuts-bolts-spacers.md): M3: (4 x bolt + 4 x nut + 4 x 40 mm spacer).
1. [on/off DC switch with indicator led](../parts/dc-switch.md): 12V DC 10 A.
1. [plexiglass, 2 mm or 2.5 mm thickness](../parts/plexiglass.md): 2 x 80 cm x 100 cm.
1. [pwm manual DC motor controller, 12 V, ≥ 5 A](../parts/pwm-manual-dc-motor-controller.md).
